@@ -1203,7 +1203,7 @@ class IPOpt(Opt):
 
 class PortOpt(Opt):
 
-    """Option for a TCP/IP port number.  Ports can range from 1 to 65535.
+    """Option for a TCP/IP port number.  Ports can range from 0 to 65535.
 
     Option with ``type`` :class:`oslo_config.types.Integer`
 
@@ -1214,8 +1214,10 @@ class PortOpt(Opt):
     .. versionadded:: 2.6
     .. versionchanged:: 3.2
        Added *choices* parameter.
+    .. versionchanged:: 3.3
+       Allow port number with 0.
     """
-    PORT_MIN = 1
+    PORT_MIN = 0
     PORT_MAX = 65535
 
     def __init__(self, name, choices=None, **kwargs):
@@ -1915,6 +1917,10 @@ class ConfigOpts(collections.Mapping):
     ConfigOpts is a configuration option manager with APIs for registering
     option schemas, grouping options, parsing option values and retrieving
     the values of options.
+
+    It has built-in support for :oslo.config:option:`config_file` and
+    :oslo.config:option:`config_dir` options.
+
     """
 
     def __init__(self):
@@ -1948,17 +1954,16 @@ class ConfigOpts(collections.Mapping):
 
         return prog, default_config_files
 
-    def _setup(self, project, prog, version, usage, default_config_files):
-        """Initialize a ConfigOpts object for option parsing."""
-
-        self._config_opts = [
+    @staticmethod
+    def _make_config_options(default_config_files):
+        return [
             _ConfigFileOpt('config-file',
                            default=default_config_files,
                            metavar='PATH',
                            help=('Path to a config file to use. Multiple '
                                  'config files can be specified, with values '
-                                 'in later files taking precedence. The '
-                                 'default files used are: %(default)s.')),
+                                 'in later files taking precedence. Defaults '
+                                 'to %(default)s.')),
             _ConfigDirOpt('config-dir',
                           metavar='DIR',
                           help='Path to a config directory to pull *.conf '
@@ -1970,6 +1975,11 @@ class ConfigOpts(collections.Mapping):
                                'over-ridden options in the directory take '
                                'precedence.'),
         ]
+
+    def _setup(self, project, prog, version, usage, default_config_files):
+        """Initialize a ConfigOpts object for option parsing."""
+
+        self._config_opts = self._make_config_options(default_config_files)
         self.register_cli_opts(self._config_opts)
 
         self.project = project
