@@ -78,7 +78,11 @@ class StringTypeTests(TypeTestHelper, unittest.TestCase):
     def test_equal_with_same_choices(self):
         t1 = types.String(choices=['foo', 'bar'])
         t2 = types.String(choices=['foo', 'bar'])
+        t3 = types.String(choices=('foo', 'bar'))
+        t4 = types.String(choices=['bar', 'foo'])
         self.assertTrue(t1 == t2)
+        self.assertTrue(t1 == t3)
+        self.assertTrue(t1 == t4)
 
     def test_not_equal_with_different_choices(self):
         t1 = types.String(choices=['foo', 'bar'])
@@ -242,6 +246,10 @@ class IntegerTypeTests(TypeTestHelper, unittest.TestCase):
         t = types.Integer(min=0, max=0)
         self.assertEqual('Integer(min=0, max=0)', repr(t))
 
+    def test_repr_with_choices(self):
+        t = types.Integer(choices=[80, 457])
+        self.assertEqual('Integer(choices=[80, 457])', repr(t))
+
     def test_equal(self):
         self.assertTrue(types.Integer() == types.Integer())
 
@@ -256,12 +264,35 @@ class IntegerTypeTests(TypeTestHelper, unittest.TestCase):
         t2 = types.Integer(min=1, max=123)
         self.assertTrue(t1 == t2)
 
+    def test_equal_with_same_choices(self):
+        t1 = types.Integer(choices=[80, 457])
+        t2 = types.Integer(choices=[457, 80])
+        self.assertTrue(t1 == t2)
+
     def test_not_equal(self):
         self.assertFalse(types.Integer(min=123) == types.Integer(min=456))
+        self.assertFalse(types.Integer(choices=[80, 457]) ==
+                         types.Integer(choices=[80, 40]))
+        self.assertFalse(types.Integer(choices=[80, 457]) ==
+                         types.Integer())
 
     def test_not_equal_to_other_class(self):
         self.assertFalse(types.Integer() == types.String())
 
+    def test_choices_with_min_max(self):
+        self.assertRaises(ValueError,
+                          types.Integer,
+                          min=10,
+                          choices=[50, 60])
+        self.assertRaises(ValueError,
+                          types.Integer,
+                          max=100,
+                          choices=[50, 60])
+        self.assertRaises(ValueError,
+                          types.Integer,
+                          min=10, max=100,
+                          choices=[50, 60])
+
     def test_min_greater_max(self):
         self.assertRaises(ValueError,
                           types.Integer,
@@ -305,6 +336,22 @@ class IntegerTypeTests(TypeTestHelper, unittest.TestCase):
         self.assertRaises(ValueError, t, 201)
         self.assertRaises(ValueError, t, -457)
 
+    def test_with_choices_list(self):
+        t = types.Integer(choices=[80, 457])
+        self.assertRaises(ValueError, t, 1)
+        self.assertRaises(ValueError, t, 200)
+        self.assertRaises(ValueError, t, -457)
+        t(80)
+        t(457)
+
+    def test_with_choices_tuple(self):
+        t = types.Integer(choices=(80, 457))
+        self.assertRaises(ValueError, t, 1)
+        self.assertRaises(ValueError, t, 200)
+        self.assertRaises(ValueError, t, -457)
+        t(80)
+        t(457)
+
 
 class FloatTypeTests(TypeTestHelper, unittest.TestCase):
     type = types.Float()
